aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/capture_info_dlg.c
diff options
context:
space:
mode:
authorUlf Lamping <ulf.lamping@web.de>2005-12-03 22:38:50 +0000
committerUlf Lamping <ulf.lamping@web.de>2005-12-03 22:38:50 +0000
commitf856dbafa830a562da34b1aaf636fb941aa5a7c9 (patch)
tree628b6300241e9d52074a65bb42ffac05b6e5fe26 /gtk/capture_info_dlg.c
parent8fdb9b2df974a38491cdcabc3e68ae2f66f15972 (diff)
split some parts of the packet counting functions into their own files capture_info(.c/.h),
so we can use it from the main program svn path=/trunk/; revision=16668
Diffstat (limited to 'gtk/capture_info_dlg.c')
-rw-r--r--gtk/capture_info_dlg.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/gtk/capture_info_dlg.c b/gtk/capture_info_dlg.c
index 6ab480fd83..8dc7b26f46 100644
--- a/gtk/capture_info_dlg.c
+++ b/gtk/capture_info_dlg.c
@@ -39,6 +39,7 @@
#include <epan/packet.h>
#include "capture.h"
#include "capture_loop.h"
+#include "capture_info.h"
#include "globals.h"
#include "capture_ui_utils.h"
#include "dlg_utils.h"
@@ -82,7 +83,7 @@ capture_info_delete_cb(GtkWidget *w _U_, GdkEvent *event _U_, gpointer data _U_)
/* create the capture info dialog */
/* will keep pointers to the fields in the counts parameter */
-void capture_info_create(
+void capture_info_ui_create(
capture_info *cinfo,
gchar *iface)
{
@@ -242,8 +243,8 @@ gchar *iface)
/* update the capture info dialog */
/* As this function is a bit time critical while capturing, */
-/* prepare everything possible in the capture_info_create() function above! */
-void capture_info_update(
+/* prepare everything possible in the capture_info_ui_create() function above! */
+void capture_info_ui_update(
capture_info *cinfo)
{
unsigned int i;
@@ -280,7 +281,7 @@ capture_info *cinfo)
/* destroy the capture info dialog again */
-void capture_info_destroy(
+void capture_info_ui_destroy(
capture_info *cinfo)
{
capture_info_ui_t *info = cinfo->ui;